meegkit.utils
=============

.. automodule:: meegkit.utils

   .. autosummary::

    auditory
    buffer
    coherence
    covariances
    denoise
    matrix
    sig
    stats
    trca

|

----

Auditory
--------
.. automodule:: meegkit.utils.auditory

   .. autosummary::


|

----

Buffer
------
.. automodule:: meegkit.utils.buffer

   .. autosummary::


|

----

Coherence
---------
.. automodule:: meegkit.utils.coherence

   .. autosummary::


|

----

Covariances
-----------
.. automodule:: meegkit.utils.covariances

   .. autosummary::


|

----

Denoising
---------
.. automodule:: meegkit.utils.denoise

   .. autosummary::


|

----

Matrix manipulation
-------------------
.. automodule:: meegkit.utils.matrix

   .. autosummary::


|

----

Signal
------
.. automodule:: meegkit.utils.sig

   .. autosummary::


|

----

Statistics
----------
.. automodule:: meegkit.utils.stats

   .. autosummary::


|

----

TRCA utilities
--------------
.. automodule:: meegkit.utils.trca

   .. autosummary::
